@@ -15,14 +15,14 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 $VERSION = eval $VERSION;
 
 
@@ -40,8 +40,8 @@ our @EXPORT_OK  = qw ( getSNTPTime );
 
 =head1 SYNOPSIS
 
-The Net::SNTP::Client - Perl module retrieves the time from an NTP or 
- SNTP server and uses the local time to calculate the roundtrip delay 
+The Net::SNTP::Client - Perl module retrieves the time from an NTP or
+ SNTP server and uses the local time to calculate the roundtrip delay
  d and system clock offset t based on RFC4330. The module is calculating
  with higher accuracy in comparison to other modules.
 
@@ -55,8 +55,8 @@ The Net::SNTP::Client - Perl module retrieves the time from an NTP or
 
 The module sends a UDP packet formated according to
  L<RFC4330|https://tools.ietf.org/html/rfc4330> to a defined NTP
- or SNTP server set by the user. The received packet, gets decoded 
- to a human readable form and also calculated the roundtrip delay 
+ or SNTP server set by the user. The received packet, gets decoded
+ to a human readable form and also calculated the roundtrip delay
  d and system clock offset t, based on the decoded data.
 
 
@@ -76,12 +76,12 @@ This module exports a single method (getSNTPTime) and returns
 =item * HOSTNAME
 
     -hostname: The mandatory key inorder the method to produce
-    an output is only the hostname, the rest of the keys are optional. 
+    an output is only the hostname, the rest of the keys are optional.
 
 
 =item * PORT
 
-    -port: By default the the port is set to 123 (NTP default port). 
+    -port: By default the the port is set to 123 (NTP default port).
     The user has the option to overwite the port based on the expected
     NTP port on the server side (e.g. -port => 123456).
 
@@ -154,23 +154,30 @@ sub getSNTPTime {
     my $error = undef;
     my %moduleInput = @_;
 
-    return ($error = "Not defined key(s)", \%moduleInput) if (_checkHashKeys(%moduleInput));
-    return ($error = "Not defined Hostname", \%moduleInput) if (!$moduleInput{-hostname});
-    return ($error = "Not correct port number", \%moduleInput) if (_verifyPort($moduleInput{-port}));
-    return ($error = "Not correct timeOut input", \%moduleInput) if (_verifyNumericInput($moduleInput{-timeOut}));
-    return ($error = "Not correct RFC4330 input", \%moduleInput) if (_verifyBoolean($moduleInput{-RFC4330}));
-    return ($error = "Not correct clearScreen input", \%moduleInput) if (_verifyBoolean($moduleInput{-clearScreen}));
+    return ($error = "Not defined key(s)", \%moduleInput)
+	if (_checkHashKeys(%moduleInput));
+    return ($error = "Not defined Hostname", \%moduleInput)
+	if (!$moduleInput{-hostname});
+    return ($error = "Not correct port number", \%moduleInput)
+	if (_verifyPort($moduleInput{-port}));
+    return ($error = "Not correct timeOut input", \%moduleInput)
+	if (_verifyNumericInput($moduleInput{-timeOut}));
+    return ($error = "Not correct RFC4330 input", \%moduleInput)
+	if (_verifyBoolean($moduleInput{-RFC4330}));
+    return ($error = "Not correct clearScreen input", \%moduleInput)
+	if (_verifyBoolean($moduleInput{-clearScreen}));
 
     my $client_socket;
     eval {
 	$client_socket = new IO::Socket::INET (
 	    PeerHost => $moduleInput{-hostname},
 	    Type     => SOCK_DGRAM,
-	    PeerPort => $moduleInput{-port} || DEFAULT_NTP_PORT, # Default NTP port 123
+	    PeerPort => $moduleInput{-port} || DEFAULT_NTP_PORT, # Default 123
 	    Proto    => 'udp'
 	    ) or die "Error Creating Socket";
     };
-    return ($error = "Problem While Creating Socket '$!'", \%moduleInput) if ( $@ && $@ =~ /Error Creating Socket/ );
+    return ($error = "Problem While Creating Socket '$!'", \%moduleInput)
+	if ( $@ && $@ =~ /Error Creating Socket/ );
 
     my %SNTP_Client_Hash = (
 	"LI"                            => 0,
@@ -208,19 +215,21 @@ sub getSNTPTime {
 			 "Transmit Timestamp Sec",
 			 "Transmit Timestamp Micro Sec" );
 
-    ( $SNTP_Client_Hash{"Transmit Timestamp Sec"} , $SNTP_Client_Hash{"Transmit Timestamp Micro Sec"} ) = gettimeofday();
-    
+    ( $SNTP_Client_Hash{"Transmit Timestamp Sec"} ,
+      $SNTP_Client_Hash{"Transmit Timestamp Micro Sec"} ) = gettimeofday();
+
     my $sendSntpPacket = pack( "B8 C3 N11",
 			       '00100011',
 			       (0) x 12,
 			       $SNTP_Client_Hash{"Transmit Timestamp Sec"},
 			       $SNTP_Client_Hash{"Transmit Timestamp Micro Sec"} );
-    
+
     eval {
 	$client_socket->send( $sendSntpPacket )
 	    or die "Error Sending";
     };
-    return ($error = "Problem While Sending '$!'", \%moduleInput) if ( $@ && $@ =~ /Error Sending/ );
+    return ($error = "Problem While Sending '$!'", \%moduleInput)
+	if ( $@ && $@ =~ /Error Sending/ );
 
     $moduleInput{-timeOut} = TIMEOUT if ( !defined $moduleInput{-timeOut});
     my $rcvSntpPacket = undef;
@@ -240,13 +249,15 @@ sub getSNTPTime {
 	return ($error = "Net::SNTP::Client timed out waiting the packet '$!'", \%moduleInput);
     }
 
-    ( $SNTP_Client_Hash{"Receive Timestamp Sec"} , $SNTP_Client_Hash{"Receive Timestamp Micro Sec"} ) = gettimeofday();
+    ( $SNTP_Client_Hash{"Receive Timestamp Sec"} ,
+      $SNTP_Client_Hash{"Receive Timestamp Micro Sec"} ) = gettimeofday();
 
     eval {
 	$client_socket->close()
 	    or die "Error Closing Socket";
     };
-    return ($error = "Problem While Clossing Socket '$!'", \%moduleInput) if ( $@ && $@ =~ /Error Closing Socket/ );
+    return ($error = "Problem While Clossing Socket '$!'", \%moduleInput)
+	if ( $@ && $@ =~ /Error Closing Socket/ );
 
     my %RcV;
     @RcV{@SNTP_Receive} = unpack("B8 C3 s n3 H8 N8" , $rcvSntpPacket);
@@ -273,19 +284,19 @@ sub getSNTPTime {
 	$RcV{"Precision"} = "-" . $RcV{"Precision"};
     }
 
-    $RcV{"Root Delay Fraction"} = 
+    $RcV{"Root Delay Fraction"} =
 	sprintf("%05d", $RcV{"Root Delay Fraction"});
-    
-    $RcV{"Root Delay"} = 
-	$RcV{"Root Delay"} . "." . $RcV{"Root Delay Fraction"};    
+
+    $RcV{"Root Delay"} =
+	$RcV{"Root Delay"} . "." . $RcV{"Root Delay Fraction"};
 
     $RcV{"Root Dispersion Fraction"} =
 	sprintf("%05d", $RcV{"Root Dispersion Fraction"});
-    
-    $RcV{"Root Dispersion"} = 
+
+    $RcV{"Root Dispersion"} =
 	$RcV{"Root Dispersion"} . "." . $RcV{"Root Dispersion Fraction"};
-    
-    $RcV{"Reference Identifier"} = 
+
+    $RcV{"Reference Identifier"} =
 	_unpackIP($RcV{"Stratum"},$RcV{"Reference Identifier"});
 
     $RcV{"Reference Timestamp Sec"} -= UNIX_EPOCH;
@@ -300,7 +311,7 @@ sub getSNTPTime {
 	(
 	 ( $RcV{"Transmit Timestamp Sec"} . "." . $RcV{"Transmit Timestamp Micro Sec"} ) -
 	 ( $RcV{"Receive Timestamp Sec"} . "." . $RcV{"Receive Timestamp Micro Sec"} )
-	) 
+	)
 	);
 
     my $t = (
@@ -319,9 +330,9 @@ sub getSNTPTime {
     (system $^O eq 'MSWin32' ? 'cls' : 'clear') if ($moduleInput{-clearScreen});
 
     my %moduleOutput = ();
-    
+
     if ( $moduleInput{-RFC4330} ) {
-	$moduleOutput{-RFC4330} = " 
+	$moduleOutput{-RFC4330} = "
 \t Timestamp Name \t ID \t When Generated
 \t ------------------------------------------------------------
 \t Originate Timestamp \t T1 \t time request sent by client
@@ -356,12 +367,12 @@ sub getSNTPTime {
 	    $RcV{"Originate Timestamp Micro Sec"}."
 \t Receive Timestamp \t ".
 	    $SNTP_Client_Hash{"Receive Timestamp Sec"}.".".$SNTP_Client_Hash{"Receive Timestamp Micro Sec"}." \t ".
-	    $RcV{"Receive Timestamp Sec"} . ".". 
+	    $RcV{"Receive Timestamp Sec"} . ".".
 	    $RcV{"Receive Timestamp Micro Sec"}."
 \t Transmit Timestamp \t ".
 	    $SNTP_Client_Hash{"Transmit Timestamp Sec"} . "." . $SNTP_Client_Hash{"Transmit Timestamp Micro Sec"}." \t ".
-	    $RcV{"Transmit Timestamp Sec"} . ".". 
-	    $RcV{"Transmit Timestamp Micro Sec"}."\n\n";
+	    $RcV{"Transmit Timestamp Sec"} . ".".
+	    $RcV{"Transmit Timestamp Micro Sec"}."";
     }
     else {
 	%moduleOutput = (
@@ -414,7 +425,6 @@ sub _checkHashKeys {
     my @keysToCompare = ( "-hostname", "-port", "-timeOut", "-RFC4330", "-clearScreen" );
     my %hashInputToCompare = @_;
     my @hashInputKeysToCompare = keys %hashInputToCompare;
-    
     my @differendKeys = _keyDifference(\@hashInputKeysToCompare, \@keysToCompare);
     if (@differendKeys) { return TRUE } else { return FALSE };
 };
@@ -457,10 +467,10 @@ sub _verifyBoolean {
 
 sub _unpackIP{
     my $ip;
-    my $stratum = shift;	
+    my $stratum = shift;
     my $tmp_ip = shift;
     if($stratum < 2){
-	$ip = unpack("A4", 
+	$ip = unpack("A4",
 		     pack("H8", $tmp_ip)
 	    );
     }else{
@@ -632,7 +642,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 16.0  2015/08/06 11:58:31 pm  Thanos
+Revision 17.0  2015/09/16 4:21:31 pm  Thanos
 
 =cut
 
